@@ -27,9 +27,8 @@ class CharmapPanel(Gtk.Box):
 
         paned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
 
-        scrolled_window = Gtk.ScrolledWindow(None, None)
+        scrolled_window = Gtk.ScrolledWindow.new(None, None)
         scrolled_window.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
-        scrolled_window.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
 
         self.view = Gucharmap.ChaptersView()
         self.view.set_headers_visible (False)
@@ -43,9 +42,8 @@ class CharmapPanel(Gtk.Box):
         scrolled_window.add(self.view)
         paned.pack1(scrolled_window, False, True)
 
-        scrolled_window = Gtk.ScrolledWindow(None, None)
+        scrolled_window = Gtk.ScrolledWindow.new(None, None)
         scrolled_window.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
-        scrolled_window.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
 
         self.chartable = Gucharmap.Chartable()
 
@@ -60,7 +58,9 @@ class CharmapPanel(Gtk.Box):
     def on_chapter_view_selection_changed(self, selection):
         model, it = selection.get_selected()
         if it:
-            codepoint_list = self.view.get_codepoint_list()
+            script_name = self.view.get_selected()
+            codepoint_list = Gucharmap.ScriptCodepointList()
+            codepoint_list.append_script(script_name)
             self.chartable.set_codepoint_list(codepoint_list)
 
     def get_chartable(self):
